searchData={"items":[{"type":"module","title":"DenoRider","doc":"","ref":"DenoRider.html"},{"type":"function","title":"DenoRider.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"DenoRider.html#child_spec/1"},{"type":"function","title":"DenoRider.eval/1","doc":"Same as `eval/2`, but it assumes that there is a process with the name\n`DenoRider` (the default if you don't provide a name to `start_link/1`).","ref":"DenoRider.html#eval/1"},{"type":"function","title":"Examples - DenoRider.eval/1","doc":"iex> DenoRider.eval(\"1 + 2\")\n    {:ok, 3}","ref":"DenoRider.html#eval/1-examples"},{"type":"function","title":"DenoRider.eval/2","doc":"Run the given JavaScript code and return the result.","ref":"DenoRider.html#eval/2"},{"type":"function","title":"Options - DenoRider.eval/2","doc":"* `:blocking` - Indicates whether the NIF call should block until the\n    JavaScript execution finishes or not. Blocking is more performant, but it\n    can also cause problems if the call takes too long. The [NIF\n    documentation](https://www.erlang.org/doc/apps/erts/erl_nif.html#lengthy_work)\n    suggests that a NIF call shouldn't take more than 1 millisecond. Only set\n    this to `true` if you need the performance boost and the execution stays\n    below 1 millisecond or so. The default is `false`.\n  * `:name` - The name of the DenoRider process. The default is\n    `DenoRider`. Can't be provided if `:runtime` is provided.\n  * `:runtime` - A runtime from `start_runtime/1`. If `:runtime` is provided,\n    `eval/2` will return a `Task` that finishes when the JavaScript exection\n    finishes. Can't be provided if `:name` is provided.","ref":"DenoRider.html#eval/2-options"},{"type":"function","title":"Examples - DenoRider.eval/2","doc":"iex> DenoRider.eval(\"1 + 2\")\n    {:ok, 3}\n\n    iex> DenoRider.eval(\"1 + 2\", blocking: true)\n    {:ok, 3}\n\n    iex> DenoRider.start_link(name: :foo)\n    iex> DenoRider.eval(\"1 + 2\", name: :foo)\n    {:ok, 3}\n\n    iex> {:ok, runtime} = DenoRider.start_runtime() |> Task.await()\n    iex> DenoRider.eval(\"1 + 2\", runtime: runtime) |> Task.await()","ref":"DenoRider.html#eval/2-examples"},{"type":"function","title":"DenoRider.start_link/1","doc":"Start a DenoRider process.","ref":"DenoRider.html#start_link/1"},{"type":"function","title":"Options - DenoRider.start_link/1","doc":"* `:name` - The name of the process.\n\nSee `start_runtime/1` for more options.","ref":"DenoRider.html#start_link/1-options"},{"type":"function","title":"Examples - DenoRider.start_link/1","doc":"iex> DenoRider.start_link(name: MyApp.DenoRider)\n    iex> DenoRider.eval(\"1 + 2\", name: MyApp.DenoRider)\n    {:ok, 3}","ref":"DenoRider.html#start_link/1-examples"},{"type":"function","title":"DenoRider.start_runtime/1","doc":"Start a JavaScript runtime and return a `Task` that finishes when runtime has\nstarted.","ref":"DenoRider.html#start_runtime/1"},{"type":"function","title":"Options - DenoRider.start_runtime/1","doc":"* `:main_module_path` - Path to the main JavaScript module. The default is to start the runtime with an empty main module.","ref":"DenoRider.html#start_runtime/1-options"},{"type":"function","title":"Examples - DenoRider.start_runtime/1","doc":"iex> DenoRider.start_runtime() |> Task.await()","ref":"DenoRider.html#start_runtime/1-examples"},{"type":"function","title":"DenoRider.stop_runtime/1","doc":"Stop a JavaScript runtime and return a `Task` that finishes when runtime has\nstopped.","ref":"DenoRider.html#stop_runtime/1"},{"type":"function","title":"Examples - DenoRider.stop_runtime/1","doc":"iex> {:ok, runtime} = DenoRider.start_runtime() |> Task.await()\n    iex> DenoRider.stop_runtime(runtime) |> Task.await()","ref":"DenoRider.html#stop_runtime/1-examples"},{"type":"module","title":"DenoRider.Native","doc":"","ref":"DenoRider.Native.html"},{"type":"function","title":"DenoRider.Native.eval/3","doc":"","ref":"DenoRider.Native.html#eval/3"},{"type":"function","title":"DenoRider.Native.eval_blocking/2","doc":"","ref":"DenoRider.Native.html#eval_blocking/2"},{"type":"function","title":"DenoRider.Native.start_runtime/1","doc":"","ref":"DenoRider.Native.html#start_runtime/1"},{"type":"function","title":"DenoRider.Native.stop_runtime/1","doc":"","ref":"DenoRider.Native.html#stop_runtime/1"},{"type":"module","title":"DenoRider.Runtime","doc":"","ref":"DenoRider.Runtime.html"},{"type":"type","title":"DenoRider.Runtime.t/0","doc":"","ref":"DenoRider.Runtime.html#t:t/0"},{"type":"exception","title":"DenoRider.Error","doc":"","ref":"DenoRider.Error.html"},{"type":"type","title":"DenoRider.Error.t/0","doc":"","ref":"DenoRider.Error.html#t:t/0"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) 2024 Andreas Geffen Lundahl\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"DenoRider","doc":"# DenoRider\n\nDenoRider is an Elixir library that embeds the [Deno](https://deno.com) runtime\nvia [Rustler](https://hexdocs.pm/rustler). It is a performant way to run\nJavaScript in Elixir and it doesn't depend on external executables.","ref":"readme.html"},{"type":"extras","title":"Installation - DenoRider","doc":"Add `:deno_rider` to your `mix.exs`:\n\n```elixir\n{:deno_rider, \"~> 0.1\"}\n```\n\nAdd `DenoRider` to your application's supervisor:\n\n```elixir\n# lib/my_app/application.ex\ndef start(_type, _args) do\n  children = [\n    ...,\n    DenoRider\n  ]\n\n  Supervisor.start_link(children, strategy: :one_for_one, name: MyApp.Supervisor)\nend\n```\n\nSee [`start_link/1`](https://hexdocs.pm/deno_rider/DenoRider.html#start_link/1)\nfor more information about options when starting DenoRider.","ref":"readme.html#installation"},{"type":"extras","title":"Precompiled NIFs - DenoRider","doc":"DenoRider provides precompiled NIFs (via\n[RustlerPrecompiled](https://hexdocs.pm/rustler_precompiled)) for the following\ntargets:\n\n* `aarch64-apple-darwin`\n* `aarch64-unknown-linux-gnu`\n* `x86_64-apple-darwin`\n* `x86_64-pc-windows-msvc`\n* `x86_64-unknown-linux-gnu`\n\nContributions for precompiling DenoRider to more targets are welcome!\n\nYou can build DenoRider yourself by setting the environment variable\n`DENO_RIDER_BUILD` to `true`.","ref":"readme.html#precompiled-nifs"},{"type":"extras","title":"Usage - DenoRider","doc":"To run JavaScript code with DenoRider, you use `eval`. For example:\n\n```elixir\niex> DenoRider.eval(\"1 + 2\")\n{:ok, 3}\niex> DenoRider.eval(\"globalThis.foo = 'bar'\")\n{:ok, \"bar\"}\niex> DenoRider.eval(\"globalThis.foo\")\n{:ok, \"bar\"}\n```\n\nSee [`eval/1`](https://hexdocs.pm/deno_rider/DenoRider.html#eval/1) and\n[`eval/2`](https://hexdocs.pm/deno_rider/DenoRider.html#eval/2) for different\nways of running JavaScript code.\n\nIf you don't want to run DenoRider as a process, you can manage the runtime\nmanually:\n\n```elixir\niex> {:ok, runtime} = DenoRider.start_runtime() |> Task.await()\n{:ok, %DenoRider.Runtime{reference: #Reference<0.328177905.1027473408.14690>}}\niex> DenoRider.eval(\"1 + 2\", runtime: runtime) |> Task.await()\n{:ok, 3}\niex> DenoRider.stop_runtime(runtime) |> Task.await()\n{:ok, nil}\n```\n\nRead the [full documentation](https://hexdocs.pm/deno_rider/DenoRider.html) for\nmore information.","ref":"readme.html#usage"},{"type":"extras","title":"FAQ - DenoRider","doc":"","ref":"readme.html#faq"},{"type":"extras","title":"When should I use DenoRider? - DenoRider","doc":"If you need to run JavaScript from Elixir, you can give DenoRider a try. Some\ncommon use cases for that is for example server-side rendering of React or\nwrapping a JavaScript library in Elixir.","ref":"readme.html#when-should-i-use-denorider"},{"type":"extras","title":"What makes DenoRider different from other ways of calling JavaScript from Elixir? - DenoRider","doc":"Since DenoRider embeds the Deno runtime, you don't need any external executables\n(such as `node`) and the latency for your JavaScript calls is very low.","ref":"readme.html#what-makes-denorider-different-from-other-ways-of-calling-javascript-from-elixir"},{"type":"extras","title":"When shouldn't I use DenoRider? - DenoRider","doc":"One reason could be that you want to use another JavaScript runtime, such as\nNode or Bun. Or if you want to use Deno features that DenoRider doesn't provide.","ref":"readme.html#when-shouldn-t-i-use-denorider"},{"type":"extras","title":"What are some common pitfalls? - DenoRider","doc":"There's currently no npm integration, which means that if you want to use an npm\npackage you first need to convert it into something that's consumable by\nDenoRider. To do that you can use [Rollup](https://rollupjs.org), for example.","ref":"readme.html#what-are-some-common-pitfalls"},{"type":"extras","title":"License - DenoRider","doc":"DenoRider is released under the MIT license. See the [LICENSE](LICENSE) file for\nmore information.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}